summaryrefslogtreecommitdiffstats
path: root/korganizer/printing
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/printing')
-rw-r--r--korganizer/printing/calprintdayconfig_base.ui22
-rw-r--r--korganizer/printing/calprintdefaultplugins.cpp46
-rw-r--r--korganizer/printing/calprintdefaultplugins.h4
-rw-r--r--korganizer/printing/calprinter.cpp14
-rw-r--r--korganizer/printing/calprinter.h10
-rw-r--r--korganizer/printing/calprintincidenceconfig_base.ui14
-rw-r--r--korganizer/printing/calprintmonthconfig_base.ui16
-rw-r--r--korganizer/printing/calprintpluginbase.cpp114
-rw-r--r--korganizer/printing/calprintpluginbase.h16
-rw-r--r--korganizer/printing/calprinttodoconfig_base.ui48
-rw-r--r--korganizer/printing/calprintweekconfig_base.ui28
-rw-r--r--korganizer/printing/cellitem.cpp6
-rw-r--r--korganizer/printing/cellitem.h4
13 files changed, 172 insertions, 170 deletions
diff --git a/korganizer/printing/calprintdayconfig_base.ui b/korganizer/printing/calprintdayconfig_base.ui
index bb1bfc0b..c16bfe63 100644
--- a/korganizer/printing/calprintdayconfig_base.ui
+++ b/korganizer/printing/calprintdayconfig_base.ui
@@ -2,7 +2,7 @@
<class>CalPrintDayConfig_Base</class>
<comment>Configuration page for the print day mode.</comment>
<author>Reinhold Kainhofer &lt;reinhold@kainhofer.com&gt;</author>
-<widget class="QWidget">
+<widget class="TQWidget">
<property name="name">
<cstring>CalPrintDay_Base</cstring>
</property>
@@ -21,7 +21,7 @@
<property name="margin">
<number>0</number>
</property>
- <widget class="QCheckBox" row="1" column="0">
+ <widget class="TQCheckBox" row="1" column="0">
<property name="name">
<cstring>mIncludeTodos</cstring>
</property>
@@ -35,7 +35,7 @@
<string>You should check this option if you want to print to-dos which are due on one of the dates which are in the supplied date range.</string>
</property>
</widget>
- <widget class="QGroupBox" row="0" column="0">
+ <widget class="TQGroupBox" row="0" column="0">
<property name="name">
<cstring>mDateRangeGroup</cstring>
</property>
@@ -80,7 +80,7 @@
</size>
</property>
</spacer>
- <widget class="QLabel" row="0" column="0">
+ <widget class="TQLabel" row="0" column="0">
<property name="name">
<cstring>mFromDateLabel</cstring>
</property>
@@ -94,7 +94,7 @@
<string>If you want to print more days at once, you can define a range of dates with this option and the &lt;i&gt;End date&lt;/i&gt; option. This option is used to define the start date.</string>
</property>
</widget>
- <widget class="QLabel" row="1" column="2">
+ <widget class="TQLabel" row="1" column="2">
<property name="name">
<cstring>mToTimeLabel</cstring>
</property>
@@ -108,7 +108,7 @@
<string>It is possible to print only those events which are inside a given timerange. With this time selection box you can define the end of this time range. The start time should be defined with the &lt;i&gt;Start time&lt;/i&gt; option. Note you can automatically modify these settings if you check &lt;i&gt;Extend time range to include all events&lt;/i&gt;.</string>
</property>
</widget>
- <widget class="QTimeEdit" row="1" column="3">
+ <widget class="TQTimeEdit" row="1" column="3">
<property name="name">
<cstring>mToTime</cstring>
</property>
@@ -126,7 +126,7 @@
<string>It's possible to print only those events which are inside a given timerange. With this time selection box you can define the end of this time range. The start time should be defined with the &lt;i&gt;Start time&lt;/i&gt; option. Note you can automatically modify these settings if you check &lt;i&gt;Extend time range to include all events&lt;/i&gt;.</string>
</property>
</widget>
- <widget class="QCheckBox" row="2" column="0" rowspan="1" colspan="5">
+ <widget class="TQCheckBox" row="2" column="0" rowspan="1" colspan="5">
<property name="name">
<cstring>mIncludeAllEvents</cstring>
</property>
@@ -148,7 +148,7 @@
<string>If you want to print more days at once, you can define a range of dates with this option and the &lt;i&gt;End date&lt;/i&gt; option. This option is used to define the start date.</string>
</property>
</widget>
- <widget class="QTimeEdit" row="0" column="3">
+ <widget class="TQTimeEdit" row="0" column="3">
<property name="name">
<cstring>mFromTime</cstring>
</property>
@@ -166,7 +166,7 @@
<string>It's possible to print only those events which are inside a given timerange. With this time selection box you can define the start of this time range. The end time should be defined with the &lt;i&gt;End time&lt;/i&gt; option. Note you can automatically modify these settings if you check &lt;i&gt;Extend time range to include all events&lt;/i&gt;.</string>
</property>
</widget>
- <widget class="QLabel" row="0" column="2">
+ <widget class="TQLabel" row="0" column="2">
<property name="name">
<cstring>mFromTimeLabel</cstring>
</property>
@@ -191,7 +191,7 @@
<string>If you want to print more days at once, you can define a range of dates with this option and the &lt;i&gt;Start date&lt;/i&gt; option. This option is used to define the end date.</string>
</property>
</widget>
- <widget class="QLabel" row="1" column="0">
+ <widget class="TQLabel" row="1" column="0">
<property name="name">
<cstring>mToDateLabel</cstring>
</property>
@@ -207,7 +207,7 @@
</widget>
</grid>
</widget>
- <widget class="QCheckBox" row="2" column="0">
+ <widget class="TQCheckBox" row="2" column="0">
<property name="name">
<cstring>mColors</cstring>
</property>
diff --git a/korganizer/printing/calprintdefaultplugins.cpp b/korganizer/printing/calprintdefaultplugins.cpp
index b62c7add..c5f69dd0 100644
--- a/korganizer/printing/calprintdefaultplugins.cpp
+++ b/korganizer/printing/calprintdefaultplugins.cpp
@@ -21,8 +21,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#ifndef KORG_NOPRINTER
@@ -144,7 +144,7 @@ class TimePrintStringsVisitor : public IncidenceBase::Visitor
event->dtStart(), event->doesFloat(), false );
} else {
mStartCaption = i18n( "No start date" );
- mStartString = TQString::null;
+ mStartString = TQString();
}
if ( event->hasEndDate() ) {
@@ -162,7 +162,7 @@ class TimePrintStringsVisitor : public IncidenceBase::Visitor
}
} else {
mEndCaption = i18n("No end date");
- mEndString = TQString::null;
+ mEndString = TQString();
}
return true;
}
@@ -173,7 +173,7 @@ class TimePrintStringsVisitor : public IncidenceBase::Visitor
todo->dtStart(), todo->doesFloat(), false );
} else {
mStartCaption = i18n( "No start date" );
- mStartString = TQString::null;
+ mStartString = TQString();
}
if ( todo->hasDueDate() ) {
@@ -182,7 +182,7 @@ class TimePrintStringsVisitor : public IncidenceBase::Visitor
todo->dtDue(), todo->doesFloat(), false );
} else {
mEndCaption = i18n("No due date");
- mEndString = TQString::null;
+ mEndString = TQString();
}
return true;
}
@@ -190,8 +190,8 @@ class TimePrintStringsVisitor : public IncidenceBase::Visitor
mStartCaption = i18n( "Start date: " );
mStartString = IncidenceFormatter::dateTimeToString(
journal->dtStart(), journal->doesFloat(), false );
- mEndCaption = TQString::null;
- mEndString = TQString::null;
+ mEndCaption = TQString();
+ mEndString = TQString();
return true;
}
};
@@ -204,12 +204,12 @@ int CalPrintIncidence::printCaptionAndText( TQPainter &p, const TQRect &box, con
TQFont oldFont( p.font() );
p.setFont( captionFont );
- p.drawText( box, Qt::AlignLeft|Qt::AlignTop|Qt::SingleLine, caption );
+ p.drawText( box, TQt::AlignLeft|TQt::AlignTop|TQt::SingleLine, caption );
if ( !text.isEmpty() ) {
textRect.setLeft( textRect.left() + textWd );
p.setFont( textFont );
- p.drawText( textRect, Qt::AlignLeft|Qt::AlignTop|Qt::SingleLine, text );
+ p.drawText( textRect, TQt::AlignLeft|TQt::AlignTop|TQt::SingleLine, text );
}
p.setFont( oldFont );
return textRect.bottom();
@@ -283,7 +283,7 @@ void CalPrintIncidence::print( TQPainter &p, int width, int height )
textRect.setLeft( textRect.right() );
textRect.setRight( timesBox.right() - padding() );
- h = QMAX( printCaptionAndText( p, textRect, stringVis.mEndCaption, stringVis.mEndString, captionFont, textFont ), h );
+ h = TQMAX( printCaptionAndText( p, textRect, stringVis.mEndCaption, stringVis.mEndString, captionFont, textFont ), h );
}
// Convert recurrence to a string
@@ -303,7 +303,7 @@ void CalPrintIncidence::print( TQPainter &p, int width, int height )
}
}
displayString.append(exceptString);
- h = QMAX( printCaptionAndText( p, recurBox, i18n( "Repeats: "), displayString, captionFont, textFont ), h );
+ h = TQMAX( printCaptionAndText( p, recurBox, i18n( "Repeats: "), displayString, captionFont, textFont ), h );
}
// Alarms Printing
@@ -359,14 +359,14 @@ void CalPrintIncidence::print( TQPainter &p, int width, int height )
txt = alarmStrings.join( i18n("Spacer for the joined list of categories", ", ") );
}
- h = QMAX( printCaptionAndText( p, alarmBox, cap, txt, captionFont, textFont ), h );
+ h = TQMAX( printCaptionAndText( p, alarmBox, cap, txt, captionFont, textFont ), h );
TQRect organizerBox( timesBox.left()+padding(), h+padding(), timesBox.right()-padding(), lineHeight );
- h = QMAX( printCaptionAndText( p, organizerBox, i18n("Organizer: "), (*it)->organizer().fullName(), captionFont, textFont ), h );
+ h = TQMAX( printCaptionAndText( p, organizerBox, i18n("Organizer: "), (*it)->organizer().fullName(), captionFont, textFont ), h );
// Finally, draw the frame around the time information...
- timesBox.setBottom( QMAX( timesBox.bottom(), h+padding() ) );
+ timesBox.setBottom( TQMAX( timesBox.bottom(), h+padding() ) );
drawBox( p, BOX_BORDER_WIDTH, timesBox );
@@ -439,10 +439,10 @@ void CalPrintIncidence::print( TQPainter &p, int width, int height )
if ( mShowSubitemsNotes ) {
if ( (*it)->relations().isEmpty() || (*it)->type() != "Todo" ) {
int notesPosition = drawBoxWithCaption( p, notesBox, i18n("Notes:"),
- TQString::null, /*sameLine=*/false, /*expand=*/false,
+ TQString(), /*sameLine=*/false, /*expand=*/false,
captionFont, textFont );
TQPen oldPen( p.pen() );
- p.setPen( Qt::DotLine );
+ p.setPen( TQt::DotLine );
while ( (notesPosition += int(1.5*lineHeight)) < notesBox.bottom() ) {
p.drawLine( notesBox.left()+padding(), notesPosition, notesBox.right()-padding(), notesPosition );
}
@@ -510,8 +510,8 @@ void CalPrintIncidence::print( TQPainter &p, int width, int height )
subitemString += datesString;
subitemString += "\n";
}
- subitemString += i18n( "subitem Status: statusString",
- "Status: %1\n").arg( statusString );
+ subitemString += i18n( "subitem tqStatus: statusString",
+ "tqStatus: %1\n").arg( statusString );
subitemString += IncidenceFormatter::recurrenceString((*rit)) + "\n";
subitemString += i18n( "subitem Priority: N",
"Priority: %1\n").arg( (*rit)->priority() );
@@ -559,7 +559,7 @@ void CalPrintIncidence::print( TQPainter &p, int width, int height )
for ( Attendee::List::ConstIterator ait = attendees.begin(); ait != attendees.end(); ++ait ) {
if ( !attendeeString.isEmpty() ) attendeeString += "\n";
attendeeString += i18n("Formatting of an attendee: "
- "'Name (Role): Status', e.g. 'Reinhold Kainhofer "
+ "'Name (Role): tqStatus', e.g. 'Reinhold Kainhofer "
"<reinhold@kainhofer.com> (Participant): Awaiting Response'",
"%1 (%2): %3")
.arg( (*ait)->fullName() )
@@ -572,7 +572,7 @@ void CalPrintIncidence::print( TQPainter &p, int width, int height )
if ( mShowOptions ) {
TQString optionsString;
if ( !(*it)->statusStr().isEmpty() ) {
- optionsString += i18n("Status: %1").arg( (*it)->statusStr() );
+ optionsString += i18n("tqStatus: %1").arg( (*it)->statusStr() );
optionsString += "\n";
}
if ( !(*it)->secrecyStr().isEmpty() ) {
@@ -740,8 +740,8 @@ void CalPrintDay::print( TQPainter &p, int width, int height )
uint lineSpacing = p.fontMetrics().lineSpacing();
uint maxAllDayEvents = 8; // the max we allow to be printed, sorry.
- uint allDayHeight = QMIN( alldayEvents.count(), maxAllDayEvents ) * lineSpacing;
- allDayHeight = QMAX( allDayHeight, ( 5 * lineSpacing ) ) + ( 2 * padding() );
+ uint allDayHeight = TQMIN( alldayEvents.count(), maxAllDayEvents ) * lineSpacing;
+ allDayHeight = TQMAX( allDayHeight, ( 5 * lineSpacing ) ) + ( 2 * padding() );
TQRect allDayBox( TIMELINE_WIDTH + padding(), headerBox.bottom() + padding(),
width - TIMELINE_WIDTH - padding(), allDayHeight );
if ( alldayEvents.count() > 0 ) {
diff --git a/korganizer/printing/calprintdefaultplugins.h b/korganizer/printing/calprintdefaultplugins.h
index a1652643..162b8a4e 100644
--- a/korganizer/printing/calprintdefaultplugins.h
+++ b/korganizer/printing/calprintdefaultplugins.h
@@ -19,8 +19,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#ifndef CALPRINTDEFAULTPLUGINS_H
#define CALPRINTDEFAULTPLUGINS_H
diff --git a/korganizer/printing/calprinter.cpp b/korganizer/printing/calprinter.cpp
index 0517dec0..0b2c098c 100644
--- a/korganizer/printing/calprinter.cpp
+++ b/korganizer/printing/calprinter.cpp
@@ -19,8 +19,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#include <tqvbuttongroup.h>
@@ -46,10 +46,10 @@
#include "calprintdefaultplugins.h"
-CalPrinter::CalPrinter( TQWidget *parent, Calendar *calendar, KOrg::CoreHelper *helper )
- : TQObject( parent, "CalPrinter" )
+CalPrinter::CalPrinter( TQWidget *tqparent, Calendar *calendar, KOrg::CoreHelper *helper )
+ : TQObject( tqparent, "CalPrinter" )
{
- mParent = parent;
+ mParent = tqparent;
mConfig = new KSimpleConfig( "korganizer_printing.rc" );
mCoreHelper = helper;
@@ -168,8 +168,8 @@ void CalPrinter::updateConfig()
/****************************************************************************/
CalPrintDialog::CalPrintDialog( KOrg::PrintPlugin::List plugins,
- TQWidget *parent, const char *name )
- : KDialogBase( parent, name, /*modal*/true, i18n("Print"), Ok | Cancel )
+ TQWidget *tqparent, const char *name )
+ : KDialogBase( tqparent, name, /*modal*/true, i18n("Print"), Ok | Cancel )
{
TQVBox *page = makeVBoxMainWidget();
diff --git a/korganizer/printing/calprinter.h b/korganizer/printing/calprinter.h
index a75d3fc6..f3e2ad2d 100644
--- a/korganizer/printing/calprinter.h
+++ b/korganizer/printing/calprinter.h
@@ -19,8 +19,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#ifndef _CALPRINTER_H
#define _CALPRINTER_H
@@ -53,6 +53,7 @@ class TQLabel;
class KDE_EXPORT CalPrinter : public TQObject, public KOrg::CalPrinterBase
{
Q_OBJECT
+ TQ_OBJECT
public:
enum ePrintOrientation {
@@ -63,7 +64,7 @@ class KDE_EXPORT CalPrinter : public TQObject, public KOrg::CalPrinterBase
};
public:
/**
- \param par parent widget for dialogs
+ \param par tqparent widget for dialogs
\param cal calendar to be printed
\param helper is a pointer to the KOrg::CoreHelper object
*/
@@ -106,9 +107,10 @@ class KDE_EXPORT CalPrinter : public TQObject, public KOrg::CalPrinterBase
class CalPrintDialog : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
CalPrintDialog( KOrg::PrintPlugin::List plugins,
- TQWidget *parent = 0, const char *name = 0 );
+ TQWidget *tqparent = 0, const char *name = 0 );
virtual ~CalPrintDialog();
KOrg::PrintPlugin *selectedPlugin();
void setOrientation( CalPrinter::ePrintOrientation orientation );
diff --git a/korganizer/printing/calprintincidenceconfig_base.ui b/korganizer/printing/calprintincidenceconfig_base.ui
index ef238b52..d3fb58d1 100644
--- a/korganizer/printing/calprintincidenceconfig_base.ui
+++ b/korganizer/printing/calprintincidenceconfig_base.ui
@@ -2,7 +2,7 @@
<class>CalPrintIncidenceConfig_Base</class>
<comment>Configuration page for printing incidences.</comment>
<author>Reinhold Kainhofer &lt;reinhold@kainhofer.com&gt;</author>
-<widget class="QWidget">
+<widget class="TQWidget">
<property name="name">
<cstring>CalPrintIncidence_Base</cstring>
</property>
@@ -21,7 +21,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QButtonGroup">
+ <widget class="TQButtonGroup">
<property name="name">
<cstring>mComponentsGroup</cstring>
</property>
@@ -35,7 +35,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>mShowDetails</cstring>
</property>
@@ -43,7 +43,7 @@
<string>Detai&amp;ls (visiblility, secrecy, etc.)</string>
</property>
</widget>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>mShowSubitemsNotes</cstring>
</property>
@@ -51,7 +51,7 @@
<string>&amp;Notes, Subitems</string>
</property>
</widget>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>mShowAttendees</cstring>
</property>
@@ -59,7 +59,7 @@
<string>&amp;Attendees</string>
</property>
</widget>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>mShowAttachments</cstring>
</property>
@@ -69,7 +69,7 @@
</widget>
</vbox>
</widget>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>mColors</cstring>
</property>
diff --git a/korganizer/printing/calprintmonthconfig_base.ui b/korganizer/printing/calprintmonthconfig_base.ui
index 6fd311ea..1a4a1b50 100644
--- a/korganizer/printing/calprintmonthconfig_base.ui
+++ b/korganizer/printing/calprintmonthconfig_base.ui
@@ -2,7 +2,7 @@
<class>CalPrintMonthConfig_Base</class>
<comment>Configuration page for the print day mode.</comment>
<author>Reinhold Kainhofer &lt;reinhold@kainhofer.com&gt;</author>
-<widget class="QWidget">
+<widget class="TQWidget">
<property name="name">
<cstring>CalPrintMonth_Base</cstring>
</property>
@@ -38,7 +38,7 @@
</size>
</property>
</spacer>
- <widget class="QGroupBox" row="0" column="0">
+ <widget class="TQGroupBox" row="0" column="0">
<property name="name">
<cstring>mDateRangeGroup</cstring>
</property>
@@ -49,7 +49,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>mFromDateLabel</cstring>
</property>
@@ -85,7 +85,7 @@
<string>When you want to print more months at once, you can define a month range. This option defines the first month to be printed. Use the on &lt;i&gt;End month&lt;/i&gt; to define the last month in this range.</string>
</property>
</widget>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>mToDateLabel</cstring>
</property>
@@ -140,7 +140,7 @@
</spacer>
</hbox>
</widget>
- <widget class="QCheckBox" row="4" column="0">
+ <widget class="TQCheckBox" row="4" column="0">
<property name="name">
<cstring>mIncludeTodos</cstring>
</property>
@@ -154,7 +154,7 @@
<string>Check this option if you want to have to-dos on the print, placed by their due date.</string>
</property>
</widget>
- <widget class="QCheckBox" row="1" column="0">
+ <widget class="TQCheckBox" row="1" column="0">
<property name="name">
<cstring>mWeekNumbers</cstring>
</property>
@@ -165,7 +165,7 @@
<string>Enable this to print week numbers at the left of each row.</string>
</property>
</widget>
- <widget class="QCheckBox" row="2" column="0">
+ <widget class="TQCheckBox" row="2" column="0">
<property name="name">
<cstring>mRecurDaily</cstring>
</property>
@@ -176,7 +176,7 @@
<string>With this option it is possible to leave out the daily recurring to-dos and events in the print. They take a lot of space and make the month view needlessly complicated.</string>
</property>
</widget>
- <widget class="QCheckBox" row="3" column="0">
+ <widget class="TQCheckBox" row="3" column="0">
<property name="name">
<cstring>mRecurWeekly</cstring>
</property>
diff --git a/korganizer/printing/calprintpluginbase.h b/korganizer/printing/calprintpluginbase.h
index 16a1cc2f..38594962 100644
--- a/korganizer/printing/calprintpluginbase.h
+++ b/korganizer/printing/calprintpluginbase.h
@@ -19,8 +19,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#ifndef CALPRINTPLUGINBASE_H
#define CALPRINTPLUGINBASE_H
@@ -200,7 +200,7 @@ class KDE_EXPORT CalPrintPluginBase : public KOrg::PrintPlugin
/**
Print the box for the given event with the given string.
- \param p QPainer of the printout
+ \param p TQPainer of the printout
\param linewidth is the width of the line used to draw the box, ignored if less than 1.
\param box Coordinates of the event's box
\param incidence The incidence (if available), from which the category
@@ -259,7 +259,7 @@ class KDE_EXPORT CalPrintPluginBase : public KOrg::PrintPlugin
It prints the given text and optionally one or two small
month views, as specified by the two TQDate. The printed
text can also contain a line feed.
- If month2 is invalid, only the month that tqcontains month1
+ If month2 is invalid, only the month that contains month1
is printed.
E.g. the filofax week view draws just the current month,
while the month view draws the previous and the next month.
@@ -419,7 +419,7 @@ class KDE_EXPORT CalPrintPluginBase : public KOrg::PrintPlugin
On the left side the time scale is printed (using drawTimeLine), then each
day gets one column (printed using drawAgendaDayBox),
and the events are displayed as boxes (like in korganizer's day/week view).
- The first cell of each column tqcontains the all-day events (using
+ The first cell of each column contains the all-day events (using
drawAllDayBox with expandable=false).
The given time range cannot be expanded to include all events.
\param p TQPainter of the printout
@@ -435,7 +435,7 @@ class KDE_EXPORT CalPrintPluginBase : public KOrg::PrintPlugin
/**
Draw the month table of the month containing the date qd. Each day gets one
- box (using drawDayBox) that tqcontains a list of all events on that day. They are arranged
+ box (using drawDayBox) that contains a list of all events on that day. They are arranged
in a matrix, with the first column being the first day of the
week (so it might display some days of the previous and the next month).
Above the matrix there is a bar showing the weekdays (drawn using drawDaysOfWeek).
@@ -478,7 +478,7 @@ class KDE_EXPORT CalPrintPluginBase : public KOrg::PrintPlugin
\param p TQPainter of the printout
\param sortField Specifies on which attribute of the todo you want to sort.
\param sortDir Specifies if you want to sort ascending or descending.
- \param connectSubTodos Whether sub-to-dos shall be connected with their parent by a line (tree-like).
+ \param connectSubTodos Whether sub-to-dos shall be connected with their tqparent by a line (tree-like).
\param strikeoutCompleted Whether completed to-dos should be printed with strike-out summaries.
\param desc Whether to print the whole description of the to-do (the summary is always printed).
\param posPriority x-coordinate where the priority is supposed to be printed. If <0, no priority will be printed.
@@ -491,7 +491,7 @@ class KDE_EXPORT CalPrintPluginBase : public KOrg::PrintPlugin
\param width width of the whole to-do list.
\param pageHeight Total height allowed for the to-do list on a page. If an to-do would be below that line, a new page is started.
\param todoList Contains a list of sub-todos for the specified @p todo .
- \param r Internal (used when printing sub-to-dos to give information about its parent)
+ \param r Internal (used when printing sub-to-dos to give information about its tqparent)
*/
void drawTodo( int &count, Todo *todo, TQPainter &p,
TodoSortField sortField, SortDirection sortDir,
diff --git a/korganizer/printing/calprinttodoconfig_base.ui b/korganizer/printing/calprinttodoconfig_base.ui
index ea2dcff2..5b330edd 100644
--- a/korganizer/printing/calprinttodoconfig_base.ui
+++ b/korganizer/printing/calprinttodoconfig_base.ui
@@ -2,7 +2,7 @@
<class>CalPrintTodoConfig_Base</class>
<comment>Configuration page for the print day mode.</comment>
<author>Reinhold Kainhofer &lt;reinhold@kainhofer.com&gt;</author>
-<widget class="QWidget">
+<widget class="TQWidget">
<property name="name">
<cstring>CalPrintTodoConfig_Base</cstring>
</property>
@@ -21,7 +21,7 @@
<property name="margin">
<number>0</number>
</property>
- <widget class="QLabel" row="0" column="0">
+ <widget class="TQLabel" row="0" column="0">
<property name="name">
<cstring>mTitleLabel</cstring>
</property>
@@ -32,7 +32,7 @@
<cstring>mTitle</cstring>
</property>
</widget>
- <widget class="QLineEdit" row="0" column="1">
+ <widget class="TQLineEdit" row="0" column="1">
<property name="name">
<cstring>mTitle</cstring>
</property>
@@ -40,7 +40,7 @@
<string>To-do List</string>
</property>
</widget>
- <widget class="QButtonGroup" row="1" column="0" rowspan="1" colspan="2">
+ <widget class="TQButtonGroup" row="1" column="0" rowspan="1" colspan="2">
<property name="name">
<cstring>mPrintType</cstring>
</property>
@@ -51,7 +51,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QRadioButton">
+ <widget class="TQRadioButton">
<property name="name">
<cstring>mPrintAll</cstring>
</property>
@@ -62,7 +62,7 @@
<bool>true</bool>
</property>
</widget>
- <widget class="QRadioButton">
+ <widget class="TQRadioButton">
<property name="name">
<cstring>mPrintUnfinished</cstring>
</property>
@@ -73,7 +73,7 @@
<string>Print &amp;unfinished to-dos only</string>
</property>
</widget>
- <widget class="QRadioButton">
+ <widget class="TQRadioButton">
<property name="name">
<cstring>mPrintDueRange</cstring>
</property>
@@ -84,7 +84,7 @@
<string>Print only to-dos due in the &amp;range:</string>
</property>
</widget>
- <widget class="QLayoutWidget">
+ <widget class="TQLayoutWidget">
<property name="name">
<cstring>tqlayout2</cstring>
</property>
@@ -109,7 +109,7 @@
</size>
</property>
</spacer>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>mFromDateLabel</cstring>
</property>
@@ -145,7 +145,7 @@
<string>If you want to print more days at once, you can define a range of dates with this option and the &lt;i&gt;End date&lt;/i&gt; option. This option is used to define the start date.</string>
</property>
</widget>
- <widget class="QLabel">
+ <widget class="TQLabel">
<property name="name">
<cstring>mToDateLabel</cstring>
</property>
@@ -202,7 +202,7 @@
</widget>
</vbox>
</widget>
- <widget class="QButtonGroup" row="2" column="0" rowspan="1" colspan="2">
+ <widget class="TQButtonGroup" row="2" column="0" rowspan="1" colspan="2">
<property name="name">
<cstring>includeInfoBox</cstring>
</property>
@@ -216,7 +216,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QCheckBox" row="1" column="0">
+ <widget class="TQCheckBox" row="1" column="0">
<property name="name">
<cstring>mPriority</cstring>
</property>
@@ -227,7 +227,7 @@
<bool>true</bool>
</property>
</widget>
- <widget class="QCheckBox" row="0" column="0">
+ <widget class="TQCheckBox" row="0" column="0">
<property name="name">
<cstring>mDescription</cstring>
</property>
@@ -238,7 +238,7 @@
<bool>true</bool>
</property>
</widget>
- <widget class="QCheckBox" row="0" column="1">
+ <widget class="TQCheckBox" row="0" column="1">
<property name="name">
<cstring>mDueDate</cstring>
</property>
@@ -252,7 +252,7 @@
<bool>true</bool>
</property>
</widget>
- <widget class="QCheckBox" row="1" column="1">
+ <widget class="TQCheckBox" row="1" column="1">
<property name="name">
<cstring>mPercentComplete</cstring>
</property>
@@ -282,7 +282,7 @@
</size>
</property>
</spacer>
- <widget class="QGroupBox" row="3" column="0" rowspan="1" colspan="2">
+ <widget class="TQGroupBox" row="3" column="0" rowspan="1" colspan="2">
<property name="name">
<cstring>sortingOptionsBox</cstring>
</property>
@@ -293,7 +293,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QLabel" row="0" column="0">
+ <widget class="TQLabel" row="0" column="0">
<property name="name">
<cstring>sortFieldLabel</cstring>
</property>
@@ -304,7 +304,7 @@
<string>Sort field:</string>
</property>
</widget>
- <widget class="QComboBox" row="0" column="1">
+ <widget class="TQComboBox" row="0" column="1">
<property name="name">
<cstring>mSortField</cstring>
</property>
@@ -312,7 +312,7 @@
<bool>true</bool>
</property>
</widget>
- <widget class="QLabel" row="1" column="0">
+ <widget class="TQLabel" row="1" column="0">
<property name="name">
<cstring>sortDirectionLabel</cstring>
</property>
@@ -323,7 +323,7 @@
<string>Sort direction:</string>
</property>
</widget>
- <widget class="QComboBox" row="1" column="1">
+ <widget class="TQComboBox" row="1" column="1">
<property name="name">
<cstring>mSortDirection</cstring>
</property>
@@ -367,7 +367,7 @@
</spacer>
</grid>
</widget>
- <widget class="QButtonGroup" row="4" column="0" rowspan="1" colspan="2">
+ <widget class="TQButtonGroup" row="4" column="0" rowspan="1" colspan="2">
<property name="name">
<cstring>otherOptionsBox</cstring>
</property>
@@ -378,18 +378,18 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>mConnectSubTodos</cstring>
</property>
<property name="text">
- <string>Co&amp;nnect sub-to-dos with its parent</string>
+ <string>Co&amp;nnect sub-to-dos with its tqparent</string>
</property>
<property name="checked">
<bool>true</bool>
</property>
</widget>
- <widget class="QCheckBox">
+ <widget class="TQCheckBox">
<property name="name">
<cstring>mStrikeOutCompleted</cstring>
</property>
diff --git a/korganizer/printing/calprintweekconfig_base.ui b/korganizer/printing/calprintweekconfig_base.ui
index 32ea6fb4..6943de85 100644
--- a/korganizer/printing/calprintweekconfig_base.ui
+++ b/korganizer/printing/calprintweekconfig_base.ui
@@ -2,7 +2,7 @@
<class>CalPrintWeekConfig_Base</class>
<comment>Configuration page for the print week mode.</comment>
<author>Reinhold Kainhofer &lt;reinhold@kainhofer.com&gt;</author>
-<widget class="QWidget">
+<widget class="TQWidget">
<property name="name">
<cstring>CalPrintWeek_Base</cstring>
</property>
@@ -41,7 +41,7 @@
</size>
</property>
</spacer>
- <widget class="QGroupBox" row="0" column="0">
+ <widget class="TQGroupBox" row="0" column="0">
<property name="name">
<cstring>mDateRangeGroup</cstring>
</property>
@@ -69,7 +69,7 @@
</size>
</property>
</spacer>
- <widget class="QLabel" row="0" column="0">
+ <widget class="TQLabel" row="0" column="0">
<property name="name">
<cstring>mFromDateLabel</cstring>
</property>
@@ -94,7 +94,7 @@
<string>Here you can choose which events should be printed based on their date. This check enables you to enter the start date of the date range. Use the &lt;i&gt;End date&lt;/i&gt; to enter the end date of the daterange.</string>
</property>
</widget>
- <widget class="QLabel" row="1" column="2">
+ <widget class="TQLabel" row="1" column="2">
<property name="name">
<cstring>mToTimeLabel</cstring>
</property>
@@ -125,7 +125,7 @@
</size>
</property>
</spacer>
- <widget class="QTimeEdit" row="1" column="3">
+ <widget class="TQTimeEdit" row="1" column="3">
<property name="name">
<cstring>mToTime</cstring>
</property>
@@ -143,7 +143,7 @@
<string>All events which start later than the given time will not be printed.</string>
</property>
</widget>
- <widget class="QLabel" row="0" column="2">
+ <widget class="TQLabel" row="0" column="2">
<property name="name">
<cstring>mFromTimeLabel</cstring>
</property>
@@ -157,7 +157,7 @@
<string>All events which start earlier than the given time will not be printed.</string>
</property>
</widget>
- <widget class="QTimeEdit" row="0" column="3">
+ <widget class="TQTimeEdit" row="0" column="3">
<property name="name">
<cstring>mFromTime</cstring>
</property>
@@ -186,7 +186,7 @@
<string>Here you can choose which events should be printed based on their date. This check enables you to enter the end date of the date range. Use the &lt;i&gt;Start date&lt;/i&gt; to enter the start date of the daterange.</string>
</property>
</widget>
- <widget class="QLabel" row="1" column="0">
+ <widget class="TQLabel" row="1" column="0">
<property name="name">
<cstring>mToDateLabel</cstring>
</property>
@@ -202,7 +202,7 @@
</widget>
</grid>
</widget>
- <widget class="QCheckBox" row="3" column="0">
+ <widget class="TQCheckBox" row="3" column="0">
<property name="name">
<cstring>mColors</cstring>
</property>
@@ -213,7 +213,7 @@
<string>The timetable view supports colors. If you want to make use of colors you should check this option. The category colors will be used.</string>
</property>
</widget>
- <widget class="QButtonGroup" row="1" column="0">
+ <widget class="TQButtonGroup" row="1" column="0">
<property name="name">
<cstring>mPrintType</cstring>
</property>
@@ -224,7 +224,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="QRadioButton" row="0" column="0" rowspan="1" colspan="5">
+ <widget class="TQRadioButton" row="0" column="0" rowspan="1" colspan="5">
<property name="name">
<cstring>mPrintTypeButton1</cstring>
</property>
@@ -238,7 +238,7 @@
<string>The Filofax view prints one week per page, so all days have a large surface.</string>
</property>
</widget>
- <widget class="QRadioButton" row="1" column="0" rowspan="1" colspan="5">
+ <widget class="TQRadioButton" row="1" column="0" rowspan="1" colspan="5">
<property name="name">
<cstring>mPrintTypeButton2</cstring>
</property>
@@ -249,7 +249,7 @@
<string>This view is similar to the weekview in KOrganizer. The week is printed in landscape tqlayout. You can even use the same colors for the items if you check &lt;i&gt;Use Colors&lt;/i&gt;.</string>
</property>
</widget>
- <widget class="QRadioButton" row="2" column="0" rowspan="1" colspan="3">
+ <widget class="TQRadioButton" row="2" column="0" rowspan="1" colspan="3">
<property name="name">
<cstring>mPrintTypeButton3</cstring>
</property>
@@ -262,7 +262,7 @@
</widget>
</grid>
</widget>
- <widget class="QCheckBox" row="2" column="0">
+ <widget class="TQCheckBox" row="2" column="0">
<property name="name">
<cstring>mIncludeTodos</cstring>
</property>
diff --git a/korganizer/printing/cellitem.cpp b/korganizer/printing/cellitem.cpp
index 73c8aa50..4dfc882f 100644
--- a/korganizer/printing/cellitem.cpp
+++ b/korganizer/printing/cellitem.cpp
@@ -18,8 +18,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#include "cellitem.h"
@@ -65,7 +65,7 @@ TQPtrList<CellItem> CellItem::placeItem( TQPtrList<CellItem> cells,
int i;
for( i = 0; i < maxSubCells; ++i ) {
kdDebug(5855) << " Trying subcell " << i << endl;
- if ( !subCellDict.find( i ) ) {
+ if ( !subCellDict.tqfind( i ) ) {
kdDebug(5855) << " Use subcell " << i << endl;
placeItem->setSubCell( i );
break;
diff --git a/korganizer/printing/cellitem.h b/korganizer/printing/cellitem.h
index 83759cc8..4217e8b9 100644
--- a/korganizer/printing/cellitem.h
+++ b/korganizer/printing/cellitem.h
@@ -18,8 +18,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#ifndef KORG_CELLITEM_H
#define KORG_CELLITEM_H
diff --git a/korganizer/printing/calprintpluginbase.cpp b/korganizer/printing/calprintpluginbase.cpp
index c0e61b92..3d330efe 100644
--- a/korganizer/printing/calprintpluginbase.cpp
+++ b/korganizer/printing/calprintpluginbase.cpp
@@ -19,8 +19,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#include <tqpainter.h>
@@ -156,7 +156,7 @@ void CalPrintPluginBase::doPrint( KPrinter *printer )
p.begin( mPrinter );
// TODO: Fix the margins!!!
// the painter initially begins at 72 dpi per the Qt docs.
// we want half-inch margins.
int margins = margin();
p.setViewport( margins, margins,
@@ -270,7 +270,7 @@ bool CalPrintPluginBase::isWorkingDay( const TQDate &dt )
TQString CalPrintPluginBase::holidayString( const TQDate &dt )
{
- return (mCoreHelper)?(mCoreHelper->holidayString(dt)):(TQString::null);
+ return (mCoreHelper)?(mCoreHelper->holidayString(dt)):(TQString());
}
@@ -387,7 +387,7 @@ void CalPrintPluginBase::printEventString( TQPainter &p, const TQRect &box, cons
{
TQRect newbox( box );
newbox.addCoords( 3, 1, -1, -1 );
- p.drawText( newbox, (flags==-1)?(Qt::AlignTop | Qt::AlignJustify | Qt::BreakAnywhere):flags, str );
+ p.drawText( newbox, (flags==-1)?(TQt::AlignTop | TQt::AlignJustify | TQt::BreakAnywhere):flags, str );
}
@@ -418,7 +418,7 @@ void CalPrintPluginBase::drawSubHeaderBox(TQPainter &p, const TQString &str, con
drawShadedBox( p, BOX_BORDER_WIDTH, TQColor( 232, 232, 232 ), box );
TQFont oldfont( p.font() );
p.setFont( TQFont( "sans-serif", 10, TQFont::Bold ) );
- p.drawText( box, Qt::AlignCenter | Qt::AlignVCenter, str );
+ p.drawText( box, TQt::AlignCenter | TQt::AlignVCenter, str );
p.setFont( oldfont );
}
@@ -429,7 +429,7 @@ void CalPrintPluginBase::drawVerticalBox( TQPainter &p, int linewidth, const TQR
p.rotate( -90 );
TQRect rotatedBox( -box.top()-box.height(), box.left(), box.height(), box.width() );
showEventBox( p, linewidth, rotatedBox, 0, str,
- ( flags == -1 ) ? Qt::AlignLeft | Qt::AlignVCenter | Qt::SingleLine : flags );
+ ( flags == -1 ) ? TQt::AlignLeft | TQt::AlignVCenter | TQt::SingleLine : flags );
p.restore();
}
@@ -455,7 +455,7 @@ int CalPrintPluginBase::drawBoxWithCaption( TQPainter &p, const TQRect &allbox,
// Bounding rectangle for caption, single-line, clip on the right
TQRect captionBox( box.left() + padding(), box.top() + padding(), 0, 0 );
p.setFont( captionFont );
- captionBox = p.boundingRect( captionBox, Qt::AlignLeft | Qt::AlignTop | Qt::SingleLine, caption );
+ captionBox = p.boundingRect( captionBox, TQt::AlignLeft | TQt::AlignTop | TQt::SingleLine, caption );
p.setFont( oldFont );
if ( captionBox.right() > box.right() )
captionBox.setRight( box.right() );
@@ -473,7 +473,7 @@ int CalPrintPluginBase::drawBoxWithCaption( TQPainter &p, const TQRect &allbox,
textBox.setRight( box.right() );
textBox.setHeight( 0 );
p.setFont( textFont );
- textBox = p.boundingRect( textBox, Qt::WordBreak | Qt::AlignTop | Qt::AlignLeft, contents );
+ textBox = p.boundingRect( textBox, TQt::WordBreak | TQt::AlignTop | TQt::AlignLeft, contents );
p.setFont( oldFont );
if ( textBox.bottom() + padding() > box.bottom() ) {
if ( expand ) {
@@ -486,10 +486,10 @@ int CalPrintPluginBase::drawBoxWithCaption( TQPainter &p, const TQRect &allbox,
drawBox( p, BOX_BORDER_WIDTH, box );
p.setFont( captionFont );
- p.drawText( captionBox, Qt::AlignLeft | Qt::AlignTop | Qt::SingleLine, caption );
+ p.drawText( captionBox, TQt::AlignLeft | TQt::AlignTop | TQt::SingleLine, caption );
if ( !contents.isEmpty() ) {
p.setFont( textFont );
- p.drawText( textBox, Qt::WordBreak | Qt::AlignTop | Qt::AlignLeft, contents );
+ p.drawText( textBox, TQt::WordBreak | TQt::AlignTop | TQt::AlignLeft, contents );
}
p.setFont( oldFont );
@@ -523,7 +523,7 @@ int CalPrintPluginBase::drawHeader( TQPainter &p, TQString title,
TQFont newFont("sans-serif", (textRect.height()<60)?16:18, TQFont::Bold);
if ( expand ) {
p.setFont( newFont );
- TQRect boundingR = p.boundingRect( textRect, Qt::AlignLeft | Qt::AlignVCenter | Qt::WordBreak, title );
+ TQRect boundingR = p.boundingRect( textRect, TQt::AlignLeft | TQt::AlignVCenter | TQt::WordBreak, title );
p.setFont( oldFont );
int h = boundingR.height();
if ( h > allbox.height() ) {
@@ -546,7 +546,7 @@ int CalPrintPluginBase::drawHeader( TQPainter &p, TQString title,
// Set the margins
p.setFont( newFont );
- p.drawText( textRect, Qt::AlignLeft | Qt::AlignVCenter | Qt::WordBreak, title );
+ p.drawText( textRect, TQt::AlignLeft | TQt::AlignVCenter | TQt::WordBreak, title );
p.setFont( oldFont );
return textRect.bottom();
@@ -587,7 +587,7 @@ void CalPrintPluginBase::drawSmallMonth(TQPainter &p, const TQDate &qd,
if ( mCalSys ) {
TQRect titleBox( box );
titleBox.setHeight( int(cellHeight+1) );
- p.drawText( titleBox, Qt::AlignTop | Qt::AlignHCenter, mCalSys->monthName( qd ) );
+ p.drawText( titleBox, TQt::AlignTop | TQt::AlignHCenter, mCalSys->monthName( qd ) );
}
// draw days of week
@@ -600,7 +600,7 @@ void CalPrintPluginBase::drawSmallMonth(TQPainter &p, const TQDate &qd,
TQString tmpStr = mCalSys->weekDayName( monthDate2 )[0].upper();
wdayBox.setLeft( int(box.left() + col*cellWidth) );
wdayBox.setRight( int(box.left() + (col+1)*cellWidth) );
- p.drawText( wdayBox, Qt::AlignCenter, tmpStr );
+ p.drawText( wdayBox, TQt::AlignCenter, tmpStr );
monthDate2 = monthDate2.addDays( 1 );
}
}
@@ -616,7 +616,7 @@ void CalPrintPluginBase::drawSmallMonth(TQPainter &p, const TQDate &qd,
TQRect dayRect( int( box.left() + col*cellWidth ), int( calStartY + row*cellHeight ), 0, 0 );
dayRect.setRight( int( box.left() + (col+1)*cellWidth ) );
dayRect.setBottom( int( calStartY + (row+1)*cellHeight ) );
- p.drawText( dayRect, Qt::AlignCenter, TQString::number( monthDate.day() ) );
+ p.drawText( dayRect, TQt::AlignCenter, TQString::number( monthDate.day() ) );
}
monthDate = monthDate.addDays(1);
}
@@ -655,7 +655,7 @@ void CalPrintPluginBase::drawDaysOfWeek(TQPainter &p,
void CalPrintPluginBase::drawDaysOfWeekBox(TQPainter &p, const TQDate &qd,
const TQRect &box )
{
- drawSubHeaderBox( p, (mCalSys)?(mCalSys->weekDayName( qd )):(TQString::null), box );
+ drawSubHeaderBox( p, (mCalSys)?(mCalSys->weekDayName( qd )):(TQString()), box );
}
@@ -699,10 +699,10 @@ void CalPrintPluginBase::drawTimeLine( TQPainter &p, const TQTime &fromTime,
p.setFont( TQFont( "sans-serif", 12, TQFont::Bold ) );
}
p.drawText( box.left() + 4, (int)currY + 2, box.width() / 2 - 2, (int)cellHeight,
- Qt::AlignTop | Qt::AlignRight, numStr );
+ TQt::AlignTop | TQt::AlignRight, numStr );
p.setFont( TQFont ( "helvetica", 10, TQFont::Normal ) );
p.drawText( xcenter + 4, (int)currY + 2, box.width() / 2 + 2, (int)(cellHeight / 2 ) - 3,
- Qt::AlignTop | Qt::AlignLeft, "00" );
+ TQt::AlignTop | TQt::AlignLeft, "00" );
} else {
p.drawLine( box.left(), (int)newY, box.right(), (int)newY );
TQTime time( curTime.hour(), 0 );
@@ -713,7 +713,7 @@ void CalPrintPluginBase::drawTimeLine( TQPainter &p, const TQTime &fromTime,
p.setFont( TQFont( "sans-serif", 12, TQFont::Bold ) ); // for dayprint
}
p.drawText( box.left() + 2, (int)currY + 2, box.width() - 4, (int)cellHeight / 2 - 3,
- Qt::AlignTop|Qt::AlignLeft, numStr );
+ TQt::AlignTop|TQt::AlignLeft, numStr );
}
currY += cellHeight;
p.setFont( oldFont );
@@ -955,10 +955,10 @@ void CalPrintPluginBase::drawDayBox( TQPainter &p, const TQDate &qd,
if (!hstring.isEmpty()) {
p.setFont( TQFont( "sans-serif", 8, TQFont::Bold, true ) );
- p.drawText( headerTextBox, Qt::AlignLeft | Qt::AlignVCenter, hstring );
+ p.drawText( headerTextBox, TQt::AlignLeft | TQt::AlignVCenter, hstring );
}
p.setFont(TQFont("sans-serif", 10, TQFont::Bold));
- p.drawText( headerTextBox, Qt::AlignRight | Qt::AlignVCenter, dayNumStr);
+ p.drawText( headerTextBox, TQt::AlignRight | TQt::AlignVCenter, dayNumStr);
Event::List eventList = mCalendar->events( qd,
EventSortStartDate,
@@ -1038,7 +1038,7 @@ void CalPrintPluginBase::drawIncidence( TQPainter &p, const TQRect &dayBox, cons
{
kdDebug(5850) << "summary = " << summary << endl;
- int flags = Qt::AlignLeft;
+ int flags = TQt::AlignLeft;
TQFontMetrics fm = p.fontMetrics();
TQRect timeBound = p.boundingRect( dayBox.x() + 5, dayBox.y() + textY,
dayBox.width() - 10, fm.lineSpacing(),
@@ -1180,7 +1180,7 @@ void CalPrintPluginBase::drawMonth( TQPainter &p, const TQDate &dt, const TQRect
if ( daysinmonth<maxdays ) {
TQRect dayBox( box.left(), daysBox.top() + round(dayheight*daysinmonth), box.width(), 0 );
dayBox.setBottom( daysBox.bottom() );
- p.fillRect( dayBox, Qt::DiagCrossPattern );
+ p.fillRect( dayBox, TQt::DiagCrossPattern );
}
// Backgrounded boxes for each day, plus day numbers
TQBrush oldbrush( p.brush() );
@@ -1195,7 +1195,7 @@ void CalPrintPluginBase::drawMonth( TQPainter &p, const TQDate &dt, const TQRect
p.drawRect( dayBox );
TQRect dateBox( dayBox );
dateBox.setWidth( dayNrWidth+3 );
- p.drawText( dateBox, Qt::AlignRight | Qt::AlignVCenter | Qt::SingleLine,
+ p.drawText( dateBox, TQt::AlignRight | TQt::AlignVCenter | TQt::SingleLine,
TQString::number(d+1) );
}
p.setBrush( oldbrush );
@@ -1318,7 +1318,7 @@ void CalPrintPluginBase::drawMonth( TQPainter &p, const TQDate &dt, const TQRect
14, 0 );
eventBox.setBottom( daysBox.top() + round( double( minsToEnd*daysBox.height()) / double(maxdays*24*60) ) );
drawVerticalBox( p, 0, eventBox, placeItem->event()->summary() );
- newxstartcont = QMAX( newxstartcont, eventBox.right() );
+ newxstartcont = TQMAX( newxstartcont, eventBox.right() );
}
xstartcont = newxstartcont;
@@ -1330,10 +1330,10 @@ void CalPrintPluginBase::drawMonth( TQPainter &p, const TQDate &dt, const TQRect
TQRect dayBox( xstartcont, daysBox.top()+round(dayheight*d), 0, 0 );
dayBox.setRight( box.right() );
dayBox.setBottom( daysBox.top()+round(dayheight*(d+1)) );
- printEventString(p, dayBox, txt, Qt::AlignTop | Qt::AlignLeft | Qt::BreakAnywhere );
+ printEventString(p, dayBox, txt, TQt::AlignTop | TQt::AlignLeft | TQt::BreakAnywhere );
}
p.setFont( oldfont );
-// p.setBrush( Qt::NoBrush );
+// p.setBrush( TQt::NoBrush );
drawBox( p, BOX_BORDER_WIDTH, borderBox );
p.restore();
}
@@ -1379,7 +1379,7 @@ void CalPrintPluginBase::drawMonthTable(TQPainter &p, const TQDate &qd, bool wee
for (int row = 0; row<rows; ++row ) {
int calWeek = weekDate.weekNumber();
TQRect rc( box.left(), rowedges[row], coledges[0] - 3 - box.left(), rowedges[row+1]-rowedges[row] );
- p.drawText( rc, Qt::AlignRight | Qt::AlignVCenter, TQString::number( calWeek ) );
+ p.drawText( rc, TQt::AlignRight | TQt::AlignVCenter, TQString::number( calWeek ) );
weekDate = weekDate.addDays( 7 );
}
p.setFont( oldFont );
@@ -1427,7 +1427,7 @@ void CalPrintPluginBase::drawTodo( int &count, Todo *todo, TQPainter &p,
TQRect rect;
TodoParentStart startpt;
- // This list keeps all starting points of the parent to-dos so the connection
+ // This list keeps all starting points of the tqparent to-dos so the connection
// lines of the tree can easily be drawn (needed if a new page is started)
static TQPtrList<TodoParentStart> startPoints;
if ( level < 1 ) {
@@ -1442,15 +1442,15 @@ void CalPrintPluginBase::drawTodo( int &count, Todo *todo, TQPainter &p,
// size of to-do
outStr=todo->summary();
int left = posSummary + ( level*10 );
- rect = p.boundingRect( left, y, ( rhs-left-5 ), -1, Qt::WordBreak, outStr );
+ rect = p.boundingRect( left, y, ( rhs-left-5 ), -1, TQt::WordBreak, outStr );
if ( !todo->description().isEmpty() && desc ) {
outStr = todo->description();
rect = p.boundingRect( left+20, rect.bottom()+5, width-(left+10-x), -1,
- Qt::WordBreak, outStr );
+ TQt::WordBreak, outStr );
}
// if too big make new page
if ( rect.bottom() > pageHeight ) {
- // first draw the connection lines from parent to-dos:
+ // first draw the connection lines from tqparent to-dos:
if ( level > 0 && connectSubTodos ) {
TodoParentStart *rct;
for ( rct = startPoints.first(); rct; rct = startPoints.next() ) {
@@ -1458,7 +1458,7 @@ void CalPrintPluginBase::drawTodo( int &count, Todo *todo, TQPainter &p,
int center = rct->mRect.left() + (rct->mRect.width()/2);
int to = p.viewport().bottom();
- // draw either from start point of parent or from top of the page
+ // draw either from start point of tqparent or from top of the page
if ( rct->mSamePage )
start = rct->mRect.bottom() + 1;
else
@@ -1473,7 +1473,7 @@ void CalPrintPluginBase::drawTodo( int &count, Todo *todo, TQPainter &p,
}
// If this is a sub-to-do, r will not be 0, and we want the LH side
- // of the priority line up to the RH side of the parent to-do's priority
+ // of the priority line up to the RH side of the tqparent to-do's priority
bool showPriority = posPriority>=0;
int lhs = posPriority;
if ( r ) {
@@ -1481,13 +1481,13 @@ void CalPrintPluginBase::drawTodo( int &count, Todo *todo, TQPainter &p,
}
outStr.setNum( todo->priority() );
- rect = p.boundingRect( lhs, y + 10, 5, -1, Qt::AlignCenter, outStr );
+ rect = p.boundingRect( lhs, y + 10, 5, -1, TQt::AlignCenter, outStr );
// Make it a more reasonable size
rect.setWidth(18);
rect.setHeight(18);
// Draw a checkbox
- p.setBrush( TQBrush( Qt::NoBrush ) );
+ p.setBrush( TQBrush( TQt::NoBrush ) );
p.drawRect( rect );
if ( todo->isCompleted() ) {
// cross out the rectangle for completed to-dos
@@ -1498,7 +1498,7 @@ void CalPrintPluginBase::drawTodo( int &count, Todo *todo, TQPainter &p,
// Priority
if ( todo->priority() > 0 && showPriority ) {
- p.drawText( rect, Qt::AlignCenter, outStr );
+ p.drawText( rect, TQt::AlignCenter, outStr );
}
startpt.mRect = rect; //save for later
@@ -1520,7 +1520,7 @@ void CalPrintPluginBase::drawTodo( int &count, Todo *todo, TQPainter &p,
// summary
outStr=todo->summary();
rect = p.boundingRect( lhs, rect.top(), (rhs-(left + rect.width() + 5)),
- -1, Qt::WordBreak, outStr );
+ -1, TQt::WordBreak, outStr );
TQRect newrect;
//FIXME: the following code prints underline rather than strikeout text
@@ -1530,12 +1530,12 @@ void CalPrintPluginBase::drawTodo( int &count, Todo *todo, TQPainter &p,
f.setStrikeOut( true );
p.setFont( f );
}
- p.drawText( rect, Qt::WordBreak, outStr, -1, &newrect );
+ p.drawText( rect, TQt::WordBreak, outStr, -1, &newrect );
f.setStrikeOut( false );
p.setFont( f );
#endif
//TODO: Remove this section when the code above is fixed
- p.drawText( rect, Qt::WordBreak, outStr, -1, &newrect );
+ p.drawText( rect, TQt::WordBreak, outStr, -1, &newrect );
if ( todo->isCompleted() && strikeoutCompleted ) {
// strike out the summary text if to-do is complete
// Note: we tried to use a strike-out font and for unknown reasons the
@@ -1552,8 +1552,8 @@ void CalPrintPluginBase::drawTodo( int &count, Todo *todo, TQPainter &p,
if ( todo->hasDueDate() && posDueDt>=0 ) {
outStr = local->formatDate( todo->dtDue().date(), true );
rect = p.boundingRect( posDueDt, y, x + width, -1,
- Qt::AlignTop | Qt::AlignLeft, outStr );
- p.drawText( rect, Qt::AlignTop | Qt::AlignLeft, outStr );
+ TQt::AlignTop | TQt::AlignLeft, outStr );
+ p.drawText( rect, TQt::AlignTop | TQt::AlignLeft, outStr );
}
// percentage completed
@@ -1564,7 +1564,7 @@ void CalPrintPluginBase::drawTodo( int &count, Todo *todo, TQPainter &p,
//first, draw the progress bar
int progress = (int)(( lwidth*todo->percentComplete())/100.0 + 0.5);
- p.setBrush( TQBrush( Qt::NoBrush ) );
+ p.setBrush( TQBrush( TQt::NoBrush ) );
p.drawRect( posPercentComplete, y+3, lwidth, lheight );
if ( progress > 0 ) {
p.setBrush( TQColor( 128, 128, 128 ) );
@@ -1574,8 +1574,8 @@ void CalPrintPluginBase::drawTodo( int &count, Todo *todo, TQPainter &p,
//now, write the percentage
outStr = i18n( "%1%" ).arg( todo->percentComplete() );
rect = p.boundingRect( posPercentComplete+lwidth+3, y, x + width, -1,
- Qt::AlignTop | Qt::AlignLeft, outStr );
- p.drawText( rect, Qt::AlignTop | Qt::AlignLeft, outStr );
+ TQt::AlignTop | TQt::AlignLeft, outStr );
+ p.drawText( rect, TQt::AlignTop | TQt::AlignLeft, outStr );
}
// description
@@ -1583,8 +1583,8 @@ void CalPrintPluginBase::drawTodo( int &count, Todo *todo, TQPainter &p,
y = newrect.bottom() + 5;
outStr = todo->description();
rect = p.boundingRect( left+20, y, x+width-(left+10), -1,
- Qt::WordBreak, outStr );
- p.drawText( rect, Qt::WordBreak, outStr, -1, &newrect );
+ TQt::WordBreak, outStr );
+ p.drawText( rect, TQt::WordBreak, outStr, -1, &newrect );
}
// Set the new line position
@@ -1650,17 +1650,17 @@ void CalPrintPluginBase::drawJournalField( TQPainter &p, TQString field, TQStrin
TQString entry( field.arg( text ) );
- TQRect rect( p.boundingRect( x, y, width, -1, Qt::WordBreak, entry) );
+ TQRect rect( p.boundingRect( x, y, width, -1, TQt::WordBreak, entry) );
if ( rect.bottom() > pageHeight) {
// Start new page...
// FIXME: If it's a multi-line text, draw a few lines on this page, and the
// remaining lines on the next page.
y=0;
mPrinter->newPage();
- rect = p.boundingRect( x, y, width, -1, Qt::WordBreak, entry);
+ rect = p.boundingRect( x, y, width, -1, TQt::WordBreak, entry);
}
TQRect newrect;
- p.drawText( rect, Qt::WordBreak, entry, -1, &newrect );
+ p.drawText( rect, TQt::WordBreak, entry, -1, &newrect );
y = newrect.bottom() + 7;
}
@@ -1681,15 +1681,15 @@ void CalPrintPluginBase::drawJournal( Journal * journal, TQPainter &p, int x, in
.arg( dateText );
}
- TQRect rect( p.boundingRect( x, y, width, -1, Qt::WordBreak, headerText) );
+ TQRect rect( p.boundingRect( x, y, width, -1, TQt::WordBreak, headerText) );
if ( rect.bottom() > pageHeight) {
// Start new page...
y=0;
mPrinter->newPage();
- rect = p.boundingRect( x, y, width, -1, Qt::WordBreak, headerText );
+ rect = p.boundingRect( x, y, width, -1, TQt::WordBreak, headerText );
}
TQRect newrect;
- p.drawText( rect, Qt::WordBreak, headerText, -1, &newrect );
+ p.drawText( rect, TQt::WordBreak, headerText, -1, &newrect );
p.setFont( oldFont );
y = newrect.bottom() + 4;
@@ -1711,7 +1711,7 @@ void CalPrintPluginBase::drawSplitHeaderRight( TQPainter &p, const TQDate &fd,
TQFont oldFont( p.font() );
TQPen oldPen( p.pen() );
- TQPen pen( Qt::black, 4 );
+ TQPen pen( TQt::black, 4 );
TQString title;
if ( mCalSys ) {
@@ -1734,7 +1734,7 @@ void CalPrintPluginBase::drawSplitHeaderRight( TQPainter &p, const TQDate &fd,
int lineSpacing = p.fontMetrics().lineSpacing();
p.drawText( 0, lineSpacing * 0, width, lineSpacing,
- Qt::AlignRight | Qt::AlignTop, title );
+ TQt::AlignRight | TQt::AlignTop, title );
title.truncate(0);
@@ -1746,7 +1746,7 @@ void CalPrintPluginBase::drawSplitHeaderRight( TQPainter &p, const TQDate &fd,
int newlineSpacing = p.fontMetrics().lineSpacing();
title += TQString::number(fd.year());
p.drawText( 0, lineSpacing * 1 + 4, width, newlineSpacing,
- Qt::AlignRight | Qt::AlignTop, title );
+ TQt::AlignRight | TQt::AlignTop, title );
p.setFont( oldFont );
}
@@ -156,7 +156,7 @@ void CalPrintPluginBase::doPrint( KPrinter *printer )
p.begin( mPrinter );
// TODO: Fix the margins!!!
- // the painter initially begins at 72 dpi per the Qt docs.
+ // the painter initially begins at 72 dpi per the TQt docs.
// we want half-inch margins.
int margins = margin();